[PATCH] md.c:structure has no member named `priority'

From: Jean-Christian de Rivaz (jcdr@lightning.ch)
Date: Tue Jul 11 2000 - 04:19:15 EST


md.c: In function `md_thread':
md.c:2911: structure has no member named `priority'
md.c: In function `md_do_sync':
md.c:3339: structure has no member named `priority'
md.c:3415: structure has no member named `priority'
md.c:3425: structure has no member named `priority'

Trivial patch:
---------------------------------------------------------------------------
--- md.c.~1~ Sat Jul 8 00:53:58 2000
+++ md.c Tue Jul 11 11:12:48 2000
@@ -2901,14 +2901,14 @@
         * high. We avoid resource deadlocks individually in each
         * raid personality. (RAID5 does preallocation) We also use RR and
         * the very same RT priority as kswapd, thus we will never get
* into a priority inversion deadlock.
         *
         * we definitely have to have equal or higher priority than
         * bdflush, otherwise bdflush will deadlock if there are too
         * many dirty RAID5 blocks.
         */
        current->policy = SCHED_OTHER;
- current->priority = 40;
+ current->nice = 40;
 // md_unlock_kernel();
 
        up(thread->sem);
@@ -3334,9 +3334,9 @@
        printk(KERN_INFO "md: using maximum available idle IO bandwith (but not
more than %d KB/sec) for reconstruction.\n", sysctl_speed_limit_max);
 
        /*
* Resync has low priority.
         */
- current->priority = 1;
+ current->nice = 1;
 
        is_mddev_idle(mddev); /* this also initializes IO event counters */
        for (m = 0; m < SYNC_MARKS; m++) {
@@ -3412,7 +3412,7 @@
                currspeed =
(j-mddev->resync_mark_cnt)/((jiffies-mddev->resync_mark)/HZ +1) +1;
 
                if (currspeed > sysctl_speed_limit_min) {
- current->priority = 1;
+ current->nice = 1;
 
                        if ((currspeed > sysctl_speed_limit_max) ||
                                        !is_mddev_idle(mddev)) {
@@ -3422,7 +3422,7 @@
                                        goto repeat;
                        }
                } else
- current->priority = 40;
+ current->nice = 40;
        }
        fsync_dev(read_disk);
        printk(KERN_INFO "md: md%d: sync done.\n",mdidx(mddev));
---------------------------------------------------------------------------

Enjoy

Jean-Christian

-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.rutgers.edu
Please read the FAQ at http://www.tux.org/lkml/
@@ -2901,14 +2901,14 @@
         * raid personality. (RAID5 does preallocation) We also use RR and
         * the very same RT priority as kswapd, thus we will never get
- * into a priority inversion deadlock.
+ * into a priority inversion deadlock. Priority is the nice field.
         *
         * we definitely have to have equal or higher priority than
@@ -3334,9 +3334,9 @@
 
        /*
- * Resync has low priority.
+ * Resync has low priority (nice).
         */



This archive was generated by hypermail 2b29 : Sat Jul 15 2000 - 21:00:12 EST